Change in ...osmo-bts[master]: osmo-bts-trx/scheduler: rx_rach_fn(): use optional TSC info from TRX

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/gerrit-log@lists.osmocom.org/.

fixeria gerrit-no-reply at lists.osmocom.org
Sun Jul 7 13:22:02 UTC 2019


fixeria has uploaded this change for review. ( https://gerrit.osmocom.org/c/osmo-bts/+/14684


Change subject: osmo-bts-trx/scheduler: rx_rach_fn(): use optional TSC info from TRX
......................................................................

osmo-bts-trx/scheduler: rx_rach_fn(): use optional TSC info from TRX

TSC (Training Sequence Code) is an optional parameter of the UL burst
indication. We need this information in order to decide whether an
Access Burst is 11-bit encoded or not (see OS#1854).

If this information is absent, we try to correlate the received synch.
sequence with the known ones (3GPP TS 05.02, section 5.2.7), and
fall-back to the default TS0 if it fails.

Since the new TRXD header version, the training sequence code is
indicated by the transceiver. Let's use it!

Change-Id: I1e654a2e49cb83c5f1e6249c0de688f99bc466b0
Related: OS#1854, OS#4006
---
M src/osmo-bts-trx/scheduler_trx.c
1 file changed, 12 insertions(+), 9 deletions(-)



  git pull ssh://gerrit.osmocom.org:29418/osmo-bts refs/changes/84/14684/1

diff --git a/src/osmo-bts-trx/scheduler_trx.c b/src/osmo-bts-trx/scheduler_trx.c
index 7bdbc4f..00d7bbb 100644
--- a/src/osmo-bts-trx/scheduler_trx.c
+++ b/src/osmo-bts-trx/scheduler_trx.c
@@ -784,19 +784,22 @@
 	uint8_t ra;
 	int rc;
 
 	/* It would be great if the transceiver were doing some kind of tagging,
 	 * whether it is extended (11-bit) RACH or not. We would not need to guess
 	 * it here. For now, let's try to correlate the synch. sequence of a received
 	 * Access Burst with the known ones (3GPP TS 05.02, section 5.2.7), and
 	 * fall-back to the default TS0 if it fails. This would save some CPU
 	 * power, and what is more important - prevent possible collisions. */
 	enum rach_synch_seq_t synch_seq = RACH_SYNCH_SEQ_TS0;
 	int best_score = 127 * RACH_SYNCH_SEQ_LEN;
 
 	/* Handover RACH cannot be extended (11-bit) */
-	if (chan == TRXC_RACH)
-		/* TODO: check for TRX_BI_F_TS_INFO flag! */
-		synch_seq = rach_get_synch_seq((sbit_t *) bi->burst, &best_score);
+	if (chan == TRXC_RACH) {
+		if (bi->flags & TRX_BI_F_TS_INFO)
+			synch_seq = (enum rach_synch_seq_t) bi->tsc;
+		else
+			synch_seq = rach_get_synch_seq((sbit_t *) bi->burst, &best_score);
+	}
 
 	LOGL1S(DL1P, LOGL_DEBUG, l1t, bi->tn, chan, bi->fn,
 	       "Received RACH (%s; match=%.1f%%) toa=%d\n",
@@ -784,19 +784,22 @@
 	int rc;
 
-	/* It would be great if the transceiver were doing some kind of tagging,
-	 * whether it is extended (11-bit) RACH or not. We would not need to guess
-	 * it here. For now, let's try to correlate the synch. sequence of a received
-	 * Access Burst with the known ones (3GPP TS 05.02, section 5.2.7), and
-	 * fall-back to the default TS0 if it fails. This would save some CPU
-	 * power, and what is more important - prevent possible collisions. */
+	/* TSC (Training Sequence Code) is an optional parameter of the UL burst
+	 * indication. We need this information in order to decide whether an
+	 * Access Burst is 11-bit encoded or not (see OS#1854). If this information
+	 * is absent, we try to correlate the received synch. sequence with the
+	 * known ones (3GPP TS 05.02, section 5.2.7), and fall-back to the default
+	 * TS0 if it fails. */
 	enum rach_synch_seq_t synch_seq = RACH_SYNCH_SEQ_TS0;
 	int best_score = 127 * RACH_SYNCH_SEQ_LEN;

-- 
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/14684
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I1e654a2e49cb83c5f1e6249c0de688f99bc466b0
Gerrit-Change-Number: 14684
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria <axilirator at gmail.com>
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.osmocom.org/pipermail/gerrit-log/attachments/20190707/fea8dd29/attachment.htm>


More information about the gerrit-log mailing list